var Lightbox = (function (exports) {
    'use strict';

    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //
    //

    var script = {
        props: {
            // images = [{ name:'image1.jpg', alt:'Redwoods', filter:'nature' }, ...]
            images: {
                type: Array,
                required: true
            },
            // Used to display a subset of photos. If used, images array must contain a property
            // titled 'filter' which contains the desired filter string
            filter: {
                type: String,
                default: 'all'
            },
            // Used if images are located in a separate folder (e.g. '/images/')
            directory: {
                type: String,
                default: ''
            },
            // Used to set the duration in miliseconds of key/mouse inactivity before caption
            // and arrows disappear
            timeoutDuration: {
                type: Number,
                default: 3000
            },
            // When true, lightbox will close when user clicks on the black backdrop
            closeOnBackdropClick: {
                type: Boolean,
                default: false
            }
        },
        data: function data() {
            return {
                visible: false,        // Lightbox not visible by default
                controlsVisible: true, // Lightbox controls (arrows, caption, close button)
                index: 0,              // Index indicates which photo to display. Default to 1st photo
                timer: null,          // Timer to show/hide lightbox controls
                slideTransitionName: "lightbox-slide-next" //Controls animation's transition direction (next or prev)
            }
        },
        mounted: function mounted() {
            window.addEventListener('keydown', this.keyEventListener);
            window.addEventListener('mousemove',this.mouseEventListener);
            window.addEventListener('touchmove',this.mouseEventListener);
            window.addEventListener('mouseup',this.mouseEventListener);
        },
        destroyed: function destroyed() {
            window.removeEventListener('keydown', this.keyEventListener);
            window.removeEventListener('mousemove',this.mouseEventListener);
            window.removeEventListener('touchmove',this.mouseEventListener);
            window.removeEventListener('mouseup',this.mouseEventListener);
        },
        methods: {
            // If closeOnBackdropClick is true, we need to close the lightbox when the user clicks on the 
            // black part of the lightbox surrounding the image. Since the image is actually set as the background
            // we can't easily determine if the click event was on the image or the rest of the background. So instead
            // we get the dimensions of the original image, determine it's actual size within the lightbox and determine if
            // the click landed within the image (knowing that the image is centered horizontally and vertically in the lightbox
            lightboxClick: function lightboxClick(event) {
                if (this.closeOnBackdropClick) {
                    var lightboxWidth = event.target.clientWidth;
                    var lightboxHeight = event.target.clientHeight;
                    var x = typeof event.clientX === 'number' ? event.clientX : 0;
                    var y = typeof event.clientY === 'number' ? event.clientY : 0;
                    var img = new Image();
                    img.src = this.directory + this.filteredImages[this.index].name;
                    var imgWidth = img.width;
                    var imgHeight = img.height;

                    if (imgWidth && imgHeight && typeof lightboxWidth === 'number' && typeof lightboxHeight === 'number') {
                        var actualImageWidth = imgWidth / imgHeight * lightboxHeight;
                        var actualImageHeight = imgHeight / imgWidth * lightboxWidth;

                        if (x < ((lightboxWidth - actualImageWidth) / 2) || x > (lightboxWidth + actualImageWidth) / 2) {
                            this.hide();
                        }
                        else if (y < ((lightboxHeight - actualImageHeight) / 2) || y > ((lightboxHeight + actualImageHeight) / 2)) {
                            this.hide();
                        }
                    }
                }
            },
            show: function show(imageName) {
                this.visible = true;
                this.controlsVisible = true;

                // Find the index of the image passed to Lightbox
                for(var i = 0; i < this.filteredImages.length; i++){
                    if(this.filteredImages[i].name == imageName) {
                        this.index = i;
                        break;
                    }
                }
                this.restartCaptionTimer();
                this.preloadNextImage();
            },
            hide: function hide() {
                this.visible = false;
                this.index = 0;
                clearTimeout(this.timer);
            },
            has_next: function has_next() {
                return (this.index + 1 < this.filteredImages.length);
            },
            has_prev: function has_prev() {
                return (this.index - 1 >= 0);
            },
            prev: function prev() {
                if (this.has_prev()) {
                    this.slideTransitionName = "lightbox-slide-prev";
                    this.index -= 1;
                }
            },
            next: function next() {
                if (this.has_next()) {
                    this.slideTransitionName = "lightbox-slide-next";
                    this.index += 1;
                    this.preloadNextImage();
                }
            },
            keyEventListener: function keyEventListener(e) {
                if (this.visible) {
                    this.controlsVisible = true;
                    this.restartCaptionTimer();

                    switch (e.key) {
                        case 'ArrowRight':
                            this.next();
                            break;
                        case 'ArrowLeft':
                            this.prev();
                            break;
                        case 'ArrowDown':
                        case 'ArrowUp':
                        case ' ':
                            e.preventDefault();
                            break;
                        case 'Escape':
                            this.hide();
                            break;
                    }
                }
            },
            // This event shows the arrows and caption on the lightbox when the mouse is moved or clicked.
            // Also used for touch events on touchscreen devices. The elements are set to disappear
            // after a given duration via a timer.
            mouseEventListener: function mouseEventListener(e) {
                if (this.visible) {
                    this.controlsVisible = true;
                    this.restartCaptionTimer();
                }
            },
            preloadNextImage: function preloadNextImage () {
                if (this.has_next()){
                    try {
                        var _img = new Image();
                        _img.src = this.directory + this.filteredImages[this.index + 1].name;
                    } catch (e) { }
                }
            },
            restartCaptionTimer: function restartCaptionTimer() {
                clearTimeout(this.timer);
                this.timer = setTimeout(function() {this.controlsVisible = false;}.bind(this), this.timeoutDuration);
            }
        },
        computed: {
            filteredImages: function () {
                if (this.filter === 'all' || !this.filter.length){
                    return this.images;
                }
                else {
                    return this.images.filter(function (item) {
                        return item.filter === this.filter;
                    }.bind(this))
                }
            }
        }
    };

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
    /* server only */
    , shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
      if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
      } // Vue.extend constructor export interop.


      var options = typeof script === 'function' ? script.options : script; // render functions

      if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true; // functional template

        if (isFunctionalTemplate) {
          options.functional = true;
        }
      } // scopedId


      if (scopeId) {
        options._scopeId = scopeId;
      }

      var hook;

      if (moduleIdentifier) {
        // server build
        hook = function hook(context) {
          // 2.3 injection
          context = context || // cached call
          this.$vnode && this.$vnode.ssrContext || // stateful
          this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
          // 2.2 with runInNewContext: true

          if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
            context = __VUE_SSR_CONTEXT__;
          } // inject component styles


          if (style) {
            style.call(this, createInjectorSSR(context));
          } // register component module identifier for async chunk inference


          if (context && context._registeredComponents) {
            context._registeredComponents.add(moduleIdentifier);
          }
        }; // used by ssr in case component is cached and beforeCreate
        // never gets called


        options._ssrRegister = hook;
      } else if (style) {
        hook = shadowMode ? function () {
          style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
        } : function (context) {
          style.call(this, createInjector(context));
        };
      }

      if (hook) {
        if (options.functional) {
          // register for functional component in vue file
          var originalRender = options.render;

          options.render = function renderWithStyleInjection(h, context) {
            hook.call(context);
            return originalRender(h, context);
          };
        } else {
          // inject component registration as beforeCreate hook
          var existing = options.beforeCreate;
          options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
      }

      return script;
    }

    var normalizeComponent_1 = normalizeComponent;

    /* script */
    var __vue_script__ = script;
    /* template */
    var __vue_render__ = function() {
      var _vm = this;
      var _h = _vm.$createElement;
      var _c = _vm._self._c || _h;
      return _c(
        "div",
        [
          _c("transition", { attrs: { name: "lightbox-fade" } }, [
            _vm.visible
              ? _c(
                  "div",
                  {
                    staticClass: "lightbox",
                    on: {
                      mousedown: function($event) {
                        $event.stopPropagation();
                        return _vm.hide($event)
                      },
                      touchdown: function($event) {
                        $event.stopPropagation();
                        return _vm.hide($event)
                      }
                    }
                  },
                  [
                    _c(
                      "div",
                      {
                        staticClass: "lightbox-close",
                        on: {
                          mousedown: function($event) {
                            $event.stopPropagation();
                            return _vm.hide($event)
                          },
                          touchdown: function($event) {
                            $event.stopPropagation();
                            return _vm.hide($event)
                          }
                        }
                      },
                      [_vm._v("×")]
                    ),
                    _vm._v(" "),
                    _c(
                      "div",
                      {
                        staticClass: "lightbox-arrow lightbox-arrow-left",
                        on: {
                          mousedown: function($event) {
                            $event.stopPropagation();
                            $event.preventDefault();
                            return _vm.prev($event)
                          },
                          touchdown: function($event) {
                            $event.stopPropagation();
                            $event.preventDefault();
                            return _vm.prev($event)
                          }
                        }
                      },
                      [
                        _c("transition", { attrs: { name: "lightbox-fade" } }, [
                          _c(
                            "div",
                            {
                              directives: [
                                {
                                  name: "show",
                                  rawName: "v-show",
                                  value: _vm.has_prev() && _vm.controlsVisible,
                                  expression: "has_prev() && controlsVisible"
                                }
                              ],
                              staticClass: "lightbox-arrow-left-icon"
                            },
                            [
                              _c(
                                "svg",
                                {
                                  attrs: {
                                    height: "24",
                                    viewBox: "0 0 24 24",
                                    width: "24",
                                    xmlns: "http://www.w3.org/2000/svg"
                                  }
                                },
                                [
                                  _c("circle", {
                                    attrs: {
                                      cx: "12",
                                      cy: "12",
                                      r: "12",
                                      fill: "rgba(20, 20, 20, 0.4)"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c("path", {
                                    attrs: {
                                      d:
                                        "M15.41 16.09l-4.58-4.59 4.58-4.59L14 5.5l-6 6 6 6z",
                                      fill: "white"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c("path", {
                                    attrs: { d: "M0-.5h24v24H0z", fill: "none" }
                                  })
                                ]
                              )
                            ]
                          )
                        ])
                      ],
                      1
                    ),
                    _vm._v(" "),
                    _c(
                      "div",
                      {
                        staticClass: "lightbox-arrow lightbox-arrow-right",
                        on: {
                          mousedown: function($event) {
                            $event.stopPropagation();
                            $event.preventDefault();
                            return _vm.next($event)
                          },
                          touchdown: function($event) {
                            $event.stopPropagation();
                            $event.preventDefault();
                            return _vm.next($event)
                          }
                        }
                      },
                      [
                        _c("transition", { attrs: { name: "lightbox-fade" } }, [
                          _c(
                            "div",
                            {
                              directives: [
                                {
                                  name: "show",
                                  rawName: "v-show",
                                  value: _vm.has_next() && _vm.controlsVisible,
                                  expression: "has_next() && controlsVisible"
                                }
                              ],
                              staticClass: "lightbox-arrow-right-icon"
                            },
                            [
                              _c(
                                "svg",
                                {
                                  attrs: {
                                    height: "24",
                                    viewBox: "0 0 24 24",
                                    width: "24",
                                    xmlns: "http://www.w3.org/2000/svg"
                                  }
                                },
                                [
                                  _c("circle", {
                                    attrs: {
                                      cx: "12",
                                      cy: "12",
                                      r: "12",
                                      fill: "rgba(20, 20, 20, 0.4)"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c("path", {
                                    attrs: {
                                      d:
                                        "M8.59 16.34l4.58-4.59-4.58-4.59L10 5.75l6 6-6 6z",
                                      fill: "white"
                                    }
                                  }),
                                  _vm._v(" "),
                                  _c("path", {
                                    attrs: { d: "M0-.25h24v24H0z", fill: "none" }
                                  })
                                ]
                              )
                            ]
                          )
                        ])
                      ],
                      1
                    ),
                    _vm._v(" "),
                    _c("transition", { attrs: { name: "lightbox-fade" } }, [
                      _c(
                        "div",
                        {
                          directives: [
                            {
                              name: "show",
                              rawName: "v-show",
                              value:
                                _vm.controlsVisible &&
                                _vm.filteredImages[_vm.index].alt,
                              expression:
                                "controlsVisible && filteredImages[index].alt"
                            }
                          ],
                          staticClass: "lightbox-caption",
                          on: {
                            mousedown: function($event) {
                              $event.stopPropagation();
                            },
                            touchdown: function($event) {
                              $event.stopPropagation();
                            }
                          }
                        },
                        [
                          _c("span", { attrs: { unselectable: "on" } }, [
                            _vm._v(_vm._s(_vm.filteredImages[_vm.index].alt))
                          ])
                        ]
                      )
                    ]),
                    _vm._v(" "),
                    _c(
                      "div",
                      {
                        staticClass: "lightbox-main",
                        on: {
                          mousedown: function($event) {
                            $event.stopPropagation();
                            return _vm.hide($event)
                          },
                          touchdown: function($event) {
                            $event.stopPropagation();
                            return _vm.hide($event)
                          }
                        }
                      },
                      [
                        _c(
                          "div",
                          {
                            staticClass: "lightbox-image-container",
                            on: {
                              mousedown: function($event) {
                                $event.stopPropagation();
                                return _vm.lightboxClick($event)
                              },
                              touchdown: function($event) {
                                $event.stopPropagation();
                                return _vm.lightboxClick($event)
                              }
                            }
                          },
                          [
                            _c(
                              "transition",
                              {
                                attrs: {
                                  name: _vm.slideTransitionName,
                                  mode: "out-in"
                                }
                              },
                              [
                                _c("div", {
                                  key: _vm.index,
                                  staticClass: "lightbox-image",
                                  style: {
                                    backgroundImage:
                                      "url(" +
                                      _vm.directory +
                                      _vm.filteredImages[_vm.index].name +
                                      ")"
                                  }
                                })
                              ]
                            )
                          ],
                          1
                        )
                      ]
                    )
                  ],
                  1
                )
              : _vm._e()
          ])
        ],
        1
      )
    };
    var __vue_staticRenderFns__ = [];
    __vue_render__._withStripped = true;

      /* style */
      var __vue_inject_styles__ = undefined;
      /* scoped */
      var __vue_scope_id__ = undefined;
      /* module identifier */
      var __vue_module_identifier__ = undefined;
      /* functional template */
      var __vue_is_functional_template__ = false;
      /* style inject */
      
      /* style inject SSR */
      

      
      var Lightbox = normalizeComponent_1(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        undefined,
        undefined
      );

    // Import vue component

    // Declare install function executed by Vue.use()
    function install(Vue) {
    	if (install.installed) { return; }
    	install.installed = true;
    	Vue.component('Lightbox', Lightbox);
    }

    // Create module definition for Vue.use()
    var plugin = {
    	install: install,
    };

    // Auto-install when vue is found (eg. in browser via <script> tag)
    var GlobalVue = null;
    if (typeof window !== 'undefined') {
    	GlobalVue = window.Vue;
    } else if (typeof global !== 'undefined') {
    	GlobalVue = global.Vue;
    }
    if (GlobalVue) {
    	GlobalVue.use(plugin);
    }

    exports.default = Lightbox;
    exports.install = install;

    Object.defineProperty(exports, '__esModule', { value: true });

    return exports;

}({}));
